@@ -44,7 +44,7 @@ Elements:
     EnrichedElement, RestrictedElement
 
 Arguments:
-    BasisFunction, TestFunction, TrialFunction
+    Argument, TestFunction, TrialFunction
 
 Coefficients:
     Coefficient, Constant, VectorConstant, TensorConstant
@@ -62,9 +62,6 @@ Indices:
     Index, indices,
     i, j, k, l, p, q, r, s
 
-Spatial coordinate:
-    x (tetrahedron.x)
-
 Scalar to tensor expression conversion:
     as_tensor, as_vector, as_matrix
 
@@ -101,7 +98,7 @@ Form transformations:
 
 """
 
-__version__ = "0.5.3"
+__version__ = "0.9.0"
 __authors__ = "Martin Sandve Alnes and Anders Logg"
 __copyright__ = "Copyright (C) 2008-2010 " + __authors__
 __license__  = "GNU GPL version 3 or any later version"
@@ -127,7 +124,8 @@ from ufl.log import get_handler, get_logger, set_handler, set_level, add_logfile
     UFLException, DEBUG, INFO, WARNING, ERROR, CRITICAL
 
 # Types for geometric quantities
-from ufl.geometry import Cell, Space, SpatialCoordinate, FacetNormal
+from ufl.geometry import Cell, Space, SpatialCoordinate, FacetNormal, CellVolume, \
+                         Circumradius
 
 # Finite elements classes
 from ufl.finiteelement import FiniteElementBase, FiniteElement, \
@@ -148,7 +146,7 @@ from ufl.coefficient import Coefficient, Coefficients, \
 from ufl.split_functions import split
 
 # Literal constants
-from ufl.constantvalue import Identity, as_ufl
+from ufl.constantvalue import Identity, Zero, as_ufl
 
 # Indexing of tensor expressions
 from ufl.indexing import Index, indices
@@ -169,7 +167,7 @@ from ufl.operators import rank, shape, \
                        sqrt, exp, ln, cos, sin, tan, acos, asin, atan, \
                        eq, ne, le, ge, lt, gt, conditional, sign, \
                        variable, diff, \
-                       Dx,  grad, div, curl, rot, Dn, \
+                       Dx,  grad, div, curl, rot, Dn, exterior_derivative,\
                        jump, avg
 
 # Lifting
@@ -188,7 +186,7 @@ from ufl.formoperators import replace, derivative, action, energy_norm, rhs, lhs
 from ufl.objects import vertex, interval, triangle, tetrahedron, quadrilateral, hexahedron, facet,\
     i, j, k, l, p, q, r, s, \
     R1, R2, R3, \
-    dx, ds, dS, dE, dc, x
+    dx, ds, dS, dE, dc
 
 # Useful constants
 from math import e, pi
