@@ -26,7 +26,7 @@ from ufl.tensoralgebra import Transposed, Outer, Inner, Dot, Cross, Trace, \
     Determinant, Inverse, Deviatoric, Cofactor
 from ufl.mathfunctions import MathFunction, Sqrt, Exp, Ln, Cos, Sin, Tan, Acos, Asin, Atan
 from ufl.restriction import Restricted, PositiveRestricted, NegativeRestricted
-from ufl.differentiation import Derivative, FunctionDerivative,\
+from ufl.differentiation import Derivative, CoefficientDerivative,\
     SpatialDerivative, VariableDerivative
 from ufl.conditional import EQ, NE, LE, GE, LT, GT, Conditional
 
@@ -121,7 +121,6 @@ class ForwardAD(Transformer):
         # Define a zero with the right indices
         # (kind of cumbersome this... any simpler way?)
         sh = o.shape() + self._var_shape
-        #sh = self._var_shape + o.shape() # DIFFSHAPE TODO: Use this version instead?
         fi = o.free_indices()
         idims = dict(o.index_dimensions())
         if self._var_free_indices:
@@ -168,7 +167,6 @@ class ForwardAD(Transformer):
             ind2 += (j,)
 
         allind = ind1 + ind2
-        #allind = ind2 + ind1 # DIFFSHAPE TODO: Use this version instead?
 
         fp = as_tensor(res, allind)
         if fi:
@@ -263,11 +261,14 @@ class ForwardAD(Transformer):
         if self._var_free_indices:
             i0, = self._var_free_indices
             i1, = i
-            msg = "Index scope collision. Try not reusing indices for multiple expressions.\n"\
-                  "An example where this occurs is (v[i]*v[i]).dx(i)*v[i] where the index i\n"\
-                  "is bound to an index sum inside the derivative w.r.t. x[i]"
-            ufl_assert(i0 != i1, msg) # TODO: Get around this with relabeling algorithm!
-
+            if i == i1:
+                error("Index scope collision. Try not reusing indices for multiple expressions.\n"\
+                      "An example where this occurs is (v[i]*v[i]).dx(i)*v[i] where the index i\n"\
+                      "is bound to an index sum inside the derivative w.r.t. x[i]")
+                # TODO: Get around this with relabeling algorithm!
+                # j = Index()
+                # A = relabel(A, { i0: j })
+                # i = (j,)
         A2, Ap = self.visit(A)
         o = self.reuse_if_possible(o, A2, i)
         op = IndexSum(Ap, i)
@@ -623,7 +624,7 @@ def forward_ad(expr, dim):
         result = compute_spatial_forward_ad(expr, dim)
     elif isinstance(expr, VariableDerivative):
         result = compute_variable_forward_ad(expr, dim)
-    elif isinstance(expr, FunctionDerivative):
+    elif isinstance(expr, CoefficientDerivative):
         result = compute_function_forward_ad(expr, dim)
     else:
         error("This shouldn't happen: expr is %s" % repr(expr))
