@@ -5,13 +5,13 @@ converting UFL expressions to other representations."""
 __authors__ = "Martin Sandve Alnes"
 __date__ = "2008-05-07 -- 2009-11-17"
 
-# Modified by Anders Logg, 2009.
-# Last changed: 2009-12-08
+# Modified by Anders Logg, 2009-2010
+# Last changed: 2010-10-25
 
 from itertools import izip
 from inspect import getargspec
 
-from ufl.log import error, warning, debug
+from ufl.log import error, warning, debug, info
 from ufl.common import Stack, StackDict
 from ufl.assertions import ufl_assert
 from ufl.finiteelement import TensorElement
@@ -339,8 +339,8 @@ class DuplicationMarker(ReuseTransformer):
             else:
                 v = o
         return v
-    basis_function = wrap_terminal
-    function = wrap_terminal
+    argument = wrap_terminal
+    coefficient = wrap_terminal
     constant = wrap_terminal
     facet_normal = wrap_terminal
 
@@ -361,9 +361,10 @@ class DuplicationMarker(ReuseTransformer):
                 self._expr2variable[e2] = v
         return v
 
-# Note:
-# To avoid typing errors, the expressions for cofactor and deviatoric parts
-# below were created with the script tensoralgebrastrings.py under ufl/scripts/
+# Note: To avoid typing errors, the expressions for cofactor and
+# deviatoric parts below were created with the script
+# tensoralgebrastrings.py under sandbox/scripts/
+
 class CompoundExpander(ReuseTransformer):
     "Expands compound expressions to equivalent representations using basic operators."
     def __init__(self, geometric_dimension):
@@ -394,9 +395,9 @@ class CompoundExpander(ReuseTransformer):
     def deviatoric(self, o, A):
         sh = self._square_matrix_shape(A)
         if sh[0] == 2:
-            return as_matrix([[-A[1,1],A[0,1]],[A[1,0],-A[0,0]]])
+            return as_matrix([[-1/2*A[1,1]+1/2*A[0,0],A[0,1]],[A[1,0],1/2*A[1,1]-1/2*A[0,0]]])
         elif sh[0] == 3:
-            return as_matrix([[-A[1,1]-A[2,2],A[0,1],A[0,2]],[A[1,0],-A[0,0]-A[2,2],A[1,2]],[A[2,0],A[2,1],-A[0,0]-A[1,1]]])
+            return as_matrix([[-1/3*A[1,1]-1/3*A[2,2]+2/3*A[0,0],A[0,1],A[0,2]],[A[1,0],2/3*A[1,1]-1/3*A[2,2]-1/3*A[0,0],A[1,2]],[A[2,0],A[2,1],-1/3*A[1,1]+2/3*A[2,2]-1/3*A[0,0]]])
         error("dev(A) not implemented for dimension %s." % sh[0])
 
     def skew(self, o, A):
@@ -512,14 +513,14 @@ class CompoundExpander(ReuseTransformer):
         return as_tensor(a.dx(jj), (jj,))
 
     def curl(self, o, a):
-        # o = curl a = "a0.dx(1)-a1.dx(0)"            if a.shape() == ()
+        # o = curl a = "[a.dx(1), -a.dx(0)]"            if a.shape() == ()
         # o = curl a = "cross(nabla, (a0, a1, 0))[2]" if a.shape() == (2,)
         # o = curl a = "cross(nabla, a)"              if a.shape() == (3,)
         def c(i, j):
             return a[j].dx(i) - a[i].dx(j)
         sh = a.shape()
         if sh == ():
-            return as_vector(a.dx(0), -a.dx(0))
+            return as_vector((a.dx(1), -a.dx(0)))
         if sh == (2,):
             return c(0,1)
         if sh == (3,):
@@ -556,7 +557,7 @@ class BasisFunctionDependencyExtracter(Transformer):
             self._variable_cache[l] = d
         return d
 
-    def basis_function(self, o):
+    def argument(self, o):
         d = frozenset((o,))
         return frozenset((d,))
 
@@ -638,9 +639,9 @@ class BasisFunctionDependencyExtracter(Transformer):
         for ad in adeps:
             # for each frozenset bd in the frozenset bdeps
             for bd in bdeps:
-                # build frozenset cd with the combined BasisFunction dependencies from ad and bd
+                # build frozenset cd with the combined Argument dependencies from ad and bd
                 cd = (ad | bd) - none
-                # build frozenset cd with the combined BasisFunction dependencies from ad and bd
+                # build frozenset cd with the combined Argument dependencies from ad and bd
                 if not len(cd) == len(ad - none) + len(bd - none):
                     raise NotMultiLinearException, repr(o)
                 # remember this dependency combination
@@ -758,8 +759,7 @@ def transform_integrands(form, transform):
                 newitg = itg.reconstruct(integrand)
                 newintegrals.append(newitg)
         if not newintegrals:
-            # TODO: Can this be a problem? We could for example return Form([]), but problems would likely arise later anyway.
-            warning("No integrals left after transformation, cannot reconstruct form.")
+            debug("No integrals left after transformation, returning empty form.")
         return Form(newintegrals)
 
     elif isinstance(form, Integral):
