@@ -16,7 +16,7 @@ from ufl.variable import Variable, Label
 from ufl.finiteelement import FiniteElementBase, FiniteElement, MixedElement, VectorElement, TensorElement
 from ufl.argument import Argument, TestFunction, TrialFunction
 from ufl.coefficient import Coefficient, ConstantBase, VectorConstant, TensorConstant, Constant
-from ufl.geometry import GeometricQuantity, SpatialCoordinate, FacetNormal, Space, Cell
+from ufl.geometry import GeometricQuantity, SpatialCoordinate, FacetNormal, Space, Cell, CellVolume, Circumradius
 from ufl.indexing import MultiIndex, Indexed, IndexBase, Index, FixedIndex, IndexSum
 from ufl.tensors import ListTensor, ComponentTensor
 from ufl.algebra import Sum, Product, Division, Power, Abs
@@ -24,7 +24,7 @@ from ufl.tensoralgebra import CompoundTensorOperator, Transposed, Outer, Inner,
 from ufl.mathfunctions import MathFunction, Sqrt, Exp, Ln, Cos, Sin, Tan, Acos, Asin, Atan
 from ufl.restriction import Restricted, PositiveRestricted, NegativeRestricted
 from ufl.lifting import LiftingResult, LiftingOperatorResult, LiftingFunctionResult, TerminalOperator, LiftingOperator, LiftingFunction
-from ufl.differentiation import Derivative, CompoundDerivative, FunctionDerivative, SpatialDerivative, VariableDerivative, Grad, Div, Curl
+from ufl.differentiation import Derivative, CompoundDerivative, CoefficientDerivative, SpatialDerivative, VariableDerivative, Grad, Div, Curl
 from ufl.conditional import Condition, EQ, NE, LE, GE, LT, GT, Conditional
 from ufl.form import Form
 from ufl.integral import Measure, Integral
