@@ -46,16 +46,16 @@ class Derivative(Operator):
     def __init__(self):
         Operator.__init__(self)
 
-class FunctionDerivative(Derivative):
+class CoefficientDerivative(Derivative):
     """Derivative of the integrand of a form w.r.t. the
-    degrees of freedom in a discrete Function."""
+    degrees of freedom in a discrete Coefficient."""
     __slots__ = ("_integrand", "_functions", "_basis_functions")
 
     def __new__(cls, integrand, functions, basis_functions):
         ufl_assert(is_true_ufl_scalar(integrand),
             "Expecting true UFL scalar expression.")
-        ufl_assert(isinstance(functions, Tuple), #and all(isinstance(f, (Function,Indexed)) for f in functions),
-            "Expecting Tuple instance with Functions.")
+        ufl_assert(isinstance(functions, Tuple), #and all(isinstance(f, (Coefficient,Indexed)) for f in functions),
+            "Expecting Tuple instance with Coefficients.")
         ufl_assert(isinstance(basis_functions, Tuple), #and all(isinstance(f, Argument) for f in basis_functions),
             "Expecting Tuple instance with Arguments.")
         if isinstance(integrand, Zero):
@@ -81,10 +81,10 @@ class FunctionDerivative(Derivative):
         return {}
 
     def __str__(self):
-        return "FunctionDerivative (w.r.t. function %s and using basis function %s) of \n%s" % (self._functions, self._basis_functions, self._integrand) # TODO: Short notation
+        return "CoefficientDerivative (w.r.t. function %s and using basis function %s) of \n%s" % (self._functions, self._basis_functions, self._integrand) # TODO: Short notation
 
     def __repr__(self):
-        return "FunctionDerivative(%r, %r, %r)" % (self._integrand, self._functions, self._basis_functions)
+        return "CoefficientDerivative(%r, %r, %r)" % (self._integrand, self._functions, self._basis_functions)
 
 def split_indices(expression, idx):
     idims = dict(expression.index_dimensions())
@@ -183,7 +183,6 @@ class VariableDerivative(Derivative):
             index_dimensions = mergedicts([f.index_dimensions(), v.index_dimensions()])
             index_dimensions = subdict(index_dimensions, free_indices)
             return Zero(f.shape() + v.shape(), free_indices, index_dimensions)
-            #return Zero(v.shape() + f.shape(), free_indices, index_dimensions) # DIFFSHAPE TODO: Use this version instead?
         return Derivative.__new__(cls)
 
     def __init__(self, f, v):
@@ -211,7 +210,6 @@ class VariableDerivative(Derivative):
         self._index_dimensions = dict(fid)
         self._index_dimensions.update(vid)
         self._shape = f.shape() + v.shape()
-        #self._shape = v.shape() + f.shape() # DIFFSHAPE TODO: Use this version instead?
         self._repr = "VariableDerivative(%r, %r)" % (self._f, self._v)
 
     def operands(self):
