@@ -6,11 +6,11 @@ __date__ = "2008-03-03"
 # Modified by Kristian B. Oelgaard
 # Modified by Marie E. Rognes (meg@simula.no) 2010
 
-# Last changed: 2010-03-22
+# Last changed: 2010-12-08
 
 from ufl.assertions import ufl_assert
 from ufl.permutation import compute_indices
-from ufl.elementlist import ufl_elements
+from ufl.elementlist import ufl_elements, aliases
 from ufl.common import product, index_to_component, component_to_index, istr
 from ufl.geometry import as_cell, domain2facet
 from ufl.log import info_blue
@@ -116,21 +116,37 @@ class FiniteElementBase(object):
 
 class FiniteElement(FiniteElementBase):
     "The basic finite element class for all simple finite elements"
-    def __init__(self, family, cell, degree):
+
+    def __init__(self, family, cell, degree=None, form_degree=None):
         "Create finite element"
+
         cell = as_cell(cell)
         domain = cell.domain()
 
+        # Check whether this family is an alias for something else
+        if family in aliases:
+            (name, cell, r) = aliases[family](family, cell, degree, form_degree)
+            info_blue("%s, is an alias for %s " % ((family, cell, degree, form_degree),
+                                                   (name, cell, r)))
+            self.__init__(name, cell, r)
+            return
+
         # Check that the element family exists
         ufl_assert(family in ufl_elements, 'Unknown finite element "%s".' % family)
 
         # Check that element data is valid (and also get common family name)
-        (family, self._short_name, value_rank, (kmin, kmax), domains) = ufl_elements[family]
+        (family, self._short_name, value_rank, krange, domains) = ufl_elements[family]
+
         ufl_assert(domain in domains or domain is None,
                    'Domain "%s" invalid for "%s" finite element.' % (domain, family))
-        ufl_assert(kmin is None or degree >= kmin or degree is None,
-                   'Degree "%s" invalid for "%s" finite element.' % (istr(degree), family))
-        ufl_assert(kmax is None or degree <= kmax or degree is None,
+        if krange is None:
+            ufl_assert(degree is None,
+                       'Degree "%s" invalid for "%s" finite element, should be None.' % (istr(degree), family))
+        else:
+            kmin, kmax = krange
+            ufl_assert(kmin is None or degree >= kmin or degree is None,
+                       'Degree "%s" invalid for "%s" finite element.' % (istr(degree), family))
+            ufl_assert(kmax is None or degree <= kmax or degree is None,
                    'Degree "%s" invalid for "%s" finite element.' % (istr(degree), family))
 
         # Set value dimension (default to using domain dimension in each axis)
