@@ -4,7 +4,7 @@ or defined as compound operators involving basic operations on the UFL
 objects."""
 
 __authors__ = "Martin Sandve Alnes and Anders Logg"
-__date__ = "2008-04-09 -- 2009-04-07"
+__date__ = "2008-04-09 -- 2010-12-04"
 
 import math
 from ufl.log import error, warning
@@ -14,38 +14,45 @@ from ufl.constantvalue import Zero, ScalarValue, as_ufl
 from ufl.differentiation import VariableDerivative, Grad, Div, Curl
 from ufl.tensoralgebra import Transposed, Inner, Outer, Dot, Cross, Determinant, Inverse, Cofactor, Trace, Deviatoric, Skew, Sym
 from ufl.variable import Variable
-from ufl.tensors import as_tensor
+from ufl.tensors import as_tensor, ListTensor
 from ufl.conditional import EQ, NE, LE, GE, LT, GT, Conditional
 from ufl.mathfunctions import Sqrt, Exp, Ln, Cos, Sin, Tan, Acos, Asin, Atan
-from ufl.indexing import indices
+from ufl.indexing import indices, Indexed
 from ufl.geometry import SpatialCoordinate
 
 #--- Basic operators ---
 
 def rank(f):
     "The rank of f."
+    f = as_ufl(f)
     return len(f.shape())
 
 def shape(f):
     "The shape of f."
+    f = as_ufl(f)
     return f.shape()
 
 #--- Tensor operators ---
 
 def transpose(A):
     "The transposed of A."
+    A = as_ufl(A)
     if A.shape() == ():
         return A
     return Transposed(A)
 
 def outer(a, b):
     "The outer product of a and b."
+    a = as_ufl(a)
+    b = as_ufl(b)
     if a.shape() == () and b.shape() == ():
         return a*b
     return Outer(a, b)
 
 def inner(a, b):
     "The inner product of a and b."
+    a = as_ufl(a)
+    b = as_ufl(b)
     if a.shape() == () and b.shape() == ():
         return a*b
     return Inner(a, b)
@@ -53,6 +60,8 @@ def inner(a, b):
 
 def dot(a, b):
     "The dot product of a and b."
+    a = as_ufl(a)
+    b = as_ufl(b)
     if a.shape() == () and b.shape() == ():
         return a*b
     return Dot(a, b)
@@ -80,44 +89,54 @@ def contraction(a, ai, b, bi):
 
 def cross(a, b):
     "The cross product of a and b."
+    a = as_ufl(a)
+    b = as_ufl(b)
     return Cross(a, b)
 
 def det(A):
     "The determinant of A."
+    A = as_ufl(A)
     if A.shape() == ():
         return A
     return Determinant(A)
 
 def inv(A):
     "The inverse of A."
+    A = as_ufl(A)
     if A.shape() == ():
-        return 1/A
+        return 1 / A
     return Inverse(A)
 
 def cofac(A):
     "The cofactor of A."
+    A = as_ufl(A)
     return Cofactor(A)
 
 def tr(A):
     "The trace of A."
+    A = as_ufl(A)
     return Trace(A)
 
 def dev(A):
     "The deviatoric part of A."
+    A = as_ufl(A)
     return Deviatoric(A)
 
 def skew(A):
     "The skew symmetric part of A."
+    A = as_ufl(A)
     return Skew(A)
 
 def sym(A):
     "The symmetric part of A."
+    A = as_ufl(A)
     return Sym(A)
 
 #--- Differential operators
 
 def Dx(f, *i):
     "The partial derivative of f with respect to spatial variable number i. Equivalent to f.dx(*i)."
+    f = as_ufl(f)
     return f.dx(*i)
 
 def Dt(f):
@@ -125,7 +144,8 @@ def Dt(f):
     raise NotImplementedError
 
 def Dn(f):
-    "The directional derivative of f in the facet normal direction, Dn(f) := dot(n, grad(f))."
+    "The directional derivative of f in the facet normal direction, Dn(f) := dot(grad(f), n)."
+    f = as_ufl(f)
     cell = f.cell()
     if cell is None:
         return Zero(f.shape(), f.free_indices(), f.index_dimensions())
@@ -142,43 +162,32 @@ def diff(f, v):
         def _diff(e):
             return diff(e, v)
         return transform_integrands(f, _diff)
+    else:
+        f = as_ufl(f)
 
     if isinstance(v, SpatialCoordinate):
-        r = v.rank()
+        r = f.rank()
         ii = indices(r + 1)
         if r:
-            v = v[ii[:-1]]
-        dv = v.dx(ii[-1])
+            f = f[ii[:-1]]
+        df = f.dx(ii[-1])
+        return as_tensor(df, ii)
 
     return VariableDerivative(f, v)
 
-def diff2(f, v): # DIFFSHAPE TODO: Replace diff with this? The difference is that the shape of v comes before the shape of f in this version.
-    "The derivative of f with respect to the variable v."
-    if isinstance(f, Form):
-        from ufl.algorithms.transformations import transform_integrands
-        def _diff(e):
-            return diff(e, v)
-        return transform_integrands(f, _diff)
-
-    if isinstance(v, SpatialCoordinate):
-        r = v.rank()
-        ii = indices(r + 1)
-        if r:
-            v = v[ii[1:]]
-        dv = v.dx(ii[0])
-        return as_tensor(dv, ii)
-    return VariableDerivative(f, v)
-
 def grad(f):
     "The gradient of f."
+    f = as_ufl(f)
     return Grad(f)
 
 def div(f):
     "The divergence of f."
+    f = as_ufl(f)
     return Div(f)
 
 def curl(f):
     "The curl of f."
+    f = as_ufl(f)
     return Curl(f)
 rot = curl
 
@@ -186,6 +195,7 @@ rot = curl
 
 def jump(v, n=None):
     "The jump of v across a facet."
+    v = as_ufl(v)
     cell = v.cell()
     if cell is None:
         warning("TODO: Not all expressions have a cell. Is it right to return zero from jump then?")
@@ -202,17 +212,21 @@ def jump(v, n=None):
             return v('+')*n('+') + v('-')*n('-')
         elif r == 1:
             return dot(v('+'), n('+')) + dot(v('-'), n('-'))
+        elif r == 2:
+            return dot(v('+'), n('+')) + dot(v('-'), n('-'))
 
-    error("jump(v, n) is only defined for scalar or vector-valued expressions (not rank %d expressions)." % r)
+    error("jump(v, n) is only defined for scalar, vector, or matrix-valued expressions (not rank %d expressions)." % r)
 
 def avg(v):
     "The average of v across a facet."
+    v = as_ufl(v)
     return 0.5*(v('+') + v('-'))
 
 #--- Other operators ---
 
 def variable(e):
     "A variable representing the given expression."
+    e = as_ufl(e)
     return Variable(e)
 
 #--- Conditional expressions ---
@@ -298,3 +312,32 @@ def asin(f):
 def atan(f):
     "The inverse tangent of f."
     return _mathfunction(f, Atan, math.atan)
+
+
+#--- Special function for exterior_derivative
+
+def exterior_derivative(f):
+
+    # meg: FIXME:
+    if isinstance(f, Indexed):
+        family = f._expression.element().family()
+    elif isinstance(f, ListTensor):
+        family = f._expressions[0]._expression.element().family()
+    else:
+        try:
+            family = f.element().family()
+        except:
+            ufl_assert(True, "Unable to determine exterior_derivative")
+
+    if "Disc" in family:
+        return f
+
+    if "Lagrange" in family:
+        return grad(f)
+
+    if "curl" in family:
+        return curl(f)
+
+    if "Brezzi" in family or "Raviart" in family:
+        return div(f)
+
